@@ -292,7 +292,7 @@ class FuseFaceRequest(AbstractModel):
         :type ModelId: str
         :param _RspImgType: 返回图像方式（url 或 base64) ，二选一。url有效期为7天。
         :type RspImgType: str
-        :param _MergeInfos: 用户人脸图片、素材模板图的人脸位置信息。
+        :param _MergeInfos: 用户人脸图片、素材模板图的人脸位置信息。不能超过6个。
         :type MergeInfos: list of MergeInfo
         :param _FuseProfileDegree: 脸型融合比例，数值越高，融合后的脸型越像素材人物。取值范围[0,100] 
 若此参数不填写，则使用人脸融合控制台中脸型参数数值。（换脸版算法暂不支持此参数调整）
@@ -431,7 +431,7 @@ class FuseFaceResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _FusedImage: RspImgType 为 url 时，返回结果的 url， RspImgType 为 base64 时返回 base64 数据。
+        :param _FusedImage: RspImgType 为 url 时，返回结果的 url（有效期7天）， RspImgType 为 base64 时返回 base64 数据。
         :type FusedImage: str
         :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
@@ -474,12 +474,12 @@ class FuseFaceUltraRequest(AbstractModel):
 目前最多支持融合模板图片中的6张人脸。
         :type MergeInfos: list of MergeInfo
         :param _ModelUrl: 素材模版图片的url地址。
-●base64 和 url 必须提供一个，如果都提供以 base64 为准。
+●base64 和 url 必须提供一个，如果都提供以 url 为准。
 ●素材图片限制：图片中面部尺寸大于34 * 34；图片尺寸大于64 * 64，小于8000 * 8000（单边限制）。图片url或者图片 base64 数据，base64 编码后大小不可超过10M（图片编码之后可能会大30%左右，建议合理控制图片大小）
 ●图片格式：支持jpg或png
         :type ModelUrl: str
         :param _ModelImage: 素材模版图片base64数据。
-●base64 和 url 必须提供一个，如果都提供以 base64 为准。
+●base64 和 url 必须提供一个，如果都提供以 url 为准。
 ●素材图片限制：图片中面部尺寸大于34 * 34；图片尺寸大于64 * 64，小于8000*8000（单边限制）。图片url或者图片 base64 数据，base64 编码后大小不可超过10M（图片编码之后可能会大30%左右，建议合理控制图片大小）
 ●支持图片格式：支持jpg或png
         :type ModelImage: str
@@ -497,11 +497,11 @@ class FuseFaceUltraRequest(AbstractModel):
 默认在融合结果图右下角添加“本图片为AI合成图片”字样，您可根据自身需要替换为其他的Logo图片。
         :type LogoParam: :class:`tencentcloud.facefusion.v20220927.models.LogoParam`
         :param _SwapModelType: 融合模型类型参数：默认为1。
-图片人脸融合（专业版）针对不同场景，提供多种模型供选择。如您的产品是泛娱乐场景，推荐使用1；如您主要用于影像场景，推荐使用5。其他模型类型也可以结合您的产品使用场景进行选择，也许会有意想不到的效果
+图片人脸融合（专业版）针对不同场景，提供多种模型供选择。如您的产品是泛娱乐场景，推荐使用1；如您主要用于影像场景，推荐使用4、5。其他模型类型也可以结合您的产品使用场景进行选择，也许会有意想不到的效果
 1：默认泛娱乐场景，画面偏锐。
 2：影视级场景，画面偏自然。
 3：影视级场景，高分辨率，画面偏自然。
-4：影视级场景，高分辨率，画面偏自然。
+4：影视级场景，高分辦率，高人脸相似度，画面偏自然，可用于证件照等场景。
 5：影视级场景，高分辨率，对闭眼和遮挡更友好。
         :type SwapModelType: int
         """
@@ -688,24 +688,33 @@ class FusionUltraParam(AbstractModel):
         r"""
         :param _WarpRadio: 拉脸强度。主要用于调整生成结果人脸脸型更像素材模板还是用户人脸。取值越大越像用户人脸。
 取值范围：0-1之间。默认取值0.7。
+
+该参数仅对SwapModelType（模型类型）取值1-5生效
 注意：此字段可能返回 null，表示取不到有效值。
         :type WarpRadio: float
         :param _EnhanceRadio: 人脸增强强度。对整个人脸进行增强，增加清晰度，改善质量。当生成的人脸不够清晰，质感不够好的时候可以设置。取值越大增强强度越大。
 取值范围：0-1之间。默认取值1。
+
+该参数仅对SwapModelType（模型类型）取值1-5生效
 注意：此字段可能返回 null，表示取不到有效值。
         :type EnhanceRadio: float
         :param _MpRadio: 磨皮强度。当生成脸的图像面部显脏时，可进行设置。
 取值范围：0-1之间。默认取值1。
+
+该参数仅对SwapModelType（模型类型）取值1-5生效
 注意：此字段可能返回 null，表示取不到有效值。
         :type MpRadio: float
         :param _BlurRadio: 人脸模糊开关（暂不支持）
 当生成人脸比较清晰时，将人脸模糊到接近模板的清晰度的程度
+
+该参数仅对SwapModelType（模型类型）取值1-5生效
 注意：此字段可能返回 null，表示取不到有效值。
         :type BlurRadio: float
         :param _TeethEnhanceRadio: 牙齿增强开关，默认取值为1
 牙齿增强，修复牙齿。当生成牙齿不好（如牙齿裂开）可以打开此开关
 0：牙齿增强关闭
 1：牙齿增强打开
+该参数仅对SwapModelType（模型类型）取值1-5生效
 注意：此字段可能返回 null，表示取不到有效值。
         :type TeethEnhanceRadio: float
         """
@@ -779,7 +788,7 @@ class ImageCodecParam(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _MetaData: 元数据
+        :param _MetaData: 元数据，个数不能大于1。
         :type MetaData: list of MetaData
         """
         self._MetaData = None
@@ -817,11 +826,15 @@ class LogoParam(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _LogoRect: 标识图片位于融合结果图中的坐标，将按照坐标对标识图片进行位置和大小的拉伸匹配
+        :param _LogoRect: 标识图片位于融合结果图中的坐标，将按照坐标对标识图片进行位置和大小的拉伸匹配。
         :type LogoRect: :class:`tencentcloud.facefusion.v20220927.models.FaceRect`
-        :param _LogoUrl: 标识图片Url地址
+        :param _LogoUrl: 标识图片Url地址。
+●base64 和 url 必须提供一个，如果都提供以 url 为准。
+●支持图片格式：支持jpg或png。
         :type LogoUrl: str
         :param _LogoImage: 标识图片base64
+●base64 和 url 必须提供一个，如果都提供以 url 为准。
+●支持图片格式：支持jpg或png。
         :type LogoImage: str
         """
         self._LogoRect = None
@@ -923,15 +936,23 @@ class MergeInfo(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _Image: 输入图片base64
+        :param _Image: 输入图片base64。
+●base64 和 url 必须提供一个，如果都提供以 url 为准。
+●素材图片限制：图片中面部尺寸大于34 * 34；图片尺寸大于64 * 64。（图片编码之后可能会大30%左右，建议合理控制图片大小）。
+●支持图片格式：支持jpg或png
         :type Image: str
-        :param _Url: 输入图片url
+        :param _Url: 输入图片url。
+●base64 和 url 必须提供一个，如果都提供以 url 为准。
+●素材图片限制：图片中面部尺寸大于34 * 34；图片尺寸大于64 * 64。（图片编码之后可能会大30%左右，建议合理控制图片大小）。
+●支持图片格式：支持jpg或png
         :type Url: str
         :param _InputImageFaceRect: 上传的图片人脸位置信息（人脸框）
+Width、Height >= 30。
         :type InputImageFaceRect: :class:`tencentcloud.facefusion.v20220927.models.FaceRect`
         :param _TemplateFaceID: 素材人脸ID，不填默认取最大人脸。
         :type TemplateFaceID: str
         :param _TemplateFaceRect: 模板中人脸位置信息(人脸框)，不填默认取最大人脸。此字段仅适用于图片融合自定义模板素材场景。
+Width、Height >= 30。
         :type TemplateFaceRect: :class:`tencentcloud.facefusion.v20220927.models.FaceRect`
         """
         self._Image = None
